@@ -75,8 +75,15 @@ class Compress(object):
         gzip_file.close()
 
         response.data = gzip_buffer.getvalue()
+
         response.headers['Content-Encoding'] = 'gzip'
-        response.headers['Vary'] = 'Accept-Encoding'
         response.headers['Content-Length'] = len(response.data)
 
+        vary = response.headers.get('Vary')
+        if vary:
+            if 'Accept-Encoding' not in vary:
+                response.headers['Vary'] = vary + ', Accept-Encoding'
+        else:
+            response.headers['Vary'] = 'Accept-Encoding'
+
         return response
